@@ -6,6 +6,7 @@ knitr::opts_chunk$set(
 
 ## ----load_data----------------------------------------------------------------
 library(mgwrsar)
+library(dplyr)
 ## loading data example
 data(mydata)
 coord=as.matrix(mydata[,c("x_lat","y_lon")])
@@ -133,9 +134,7 @@ summary_mgwrsar(mgwrsar_1_kc_kv)
 mgwrsar_1_kc_0<-MGWRSAR(formula = 'Y_mgwrsar_1_kc_kv~X1+X2+X3', data = mydata,coord=coord, fixed_vars=c('Intercept','X1','X2','X3'),kernels=c('gauss'),H=20, Model = 'MGWRSAR_1_kc_0',control=list(SE=F,adaptive=T,W=W))
 summary_mgwrsar(mgwrsar_1_kc_0)
 
-
 ## ----Prediction1--------------------------------------------------------------
-
 length_out=800
 index_in=sample(1:1000,length_out)
 index_out=(1:1000)[-index_in]
@@ -143,7 +142,6 @@ index_out=(1:1000)[-index_in]
 model_GWR_insample<-MGWRSAR(formula = 'Y_gwr~X1+X2+X3', data = mydata[index_in,],coord=coord[index_in,], fixed_vars=NULL,kernels=c('gauss'),H=8, Model = 'GWR',control=list(adaptive=T))
 summary_mgwrsar(model_GWR_insample)
 
-
 newdata=mydata[index_out,]
 newdata_coord=coord[index_out,]
 newdata$Y_mgwrsar_1_0_kv=0
@@ -153,12 +151,6 @@ head(Y_pred)
 head(mydata$Y_gwr[index_out])
 sqrt(mean((mydata$Y_gwr[index_out]-Y_pred)^2)) # RMSE
 
-## to get prediction without computing the initial model
-Y_pred2=as.numeric((MGWRSAR( 'Y_gwr~X1+X2+X3', data = mydata[index_in,],coord=coord[index_in,], fixed_vars=NULL,kernels=c('gauss'),H=8, Model = 'GWR',control=list(adaptive=T, S_out = coord[index_out,], new_data = mydata[index_out,])))$pred)
-
-
-
-
 model_MGWR_insample<-MGWRSAR(formula = 'Y_gwr~X1+X2+X3', data = mydata[index_in,],coord=coord[index_in,], fixed_vars='X3',kernels=c('gauss'),H=8, Model = 'MGWR',control=list(adaptive=T))
 summary_mgwrsar(model_MGWR_insample)
 
@@ -173,7 +165,6 @@ head(mydata$Y_gwr[index_out])
 sqrt(mean((mydata$Y_gwr[index_out]-Y_pred)^2)) # RMSE
 
 
-
 ## ----Prediction2--------------------------------------------------------------
 
 length_out=800
@@ -294,7 +285,7 @@ RMSE_BPN
 #  summary_mgwrsar(model_GWR)
 
 ## ----bandwidths_mgwrsar1,eval=FALSE-------------------------------------------
-#  mytab<-bandwidths_mgwrsar(formula = 'Y_gwr~X1+X2+X3', data = mydata,coord=coord, fixed_vars=c('Intercept','X1'),Models=c('GWR','MGWR'),Kernels=c('bisq','gauss'),control=list(NN=300,adaptive=TRUE),control_search=list())
+#  mytab<-bandwidths_mgwrsar(formula = 'Y_gwr~X1+X2+X3', data = mydata,coord=coord, fixed_vars=c('Intercept','X1'),Models=c('GWR','MGWR'),candidates_Kernels=c('bisq','gauss'),control=list(NN=300,adaptive=TRUE),control_search=list())
 #  
 #  names(mytab)
 #  names(mytab[['GWR_bisq_adaptive']])
@@ -306,7 +297,7 @@ RMSE_BPN
 #  mybestmodel=mytab[['GWR_gauss_adaptive']]$model
 
 ## ----bandwidths_mgwrsar2, eval=FALSE------------------------------------------
-#  mytab2<-bandwidths_mgwrsar(formula='Y_gwr~X1+X2+X3', data = mydata,coord=coord, fixed_vars=NULL,Models=c('MGWRSAR_0_0_kv'),Kernels_candidates=c('bisq'),control=list(adaptive=TRUE,NN=500),control_search=list(search_W=TRUE,kernel_w='rectangle',adaptive_W=TRUE))
+#  mytab2<-bandwidths_mgwrsar(formula='Y_gwr~X1+X2+X3', data = mydata,coord=coord, fixed_vars=NULL,Models=c('MGWRSAR_0_0_kv'),candidates_Kernels=c('bisq'),control=list(adaptive=TRUE,NN=500),control_search=list(search_W=TRUE,kernel_w='rectangle',adaptive_W=TRUE))
 #  
 #  names(mytab2)
 #  mytab2[['MGWRSAR_0_0_kv_bisq_adaptive']]$config_model
